searchData={"items":[{"type":"module","title":"Exflect","doc":"","ref":"Exflect.html"},{"type":"function","title":"Exflect.inflect/3","doc":"Inflects the input word based on the the integer given.\n\n```elixir\niex> Exflect.inflect(\"leaf\", 0)\n\"leaves\"\niex> Exflect.inflect(\"leaf\", 1)\n\"leaf\"\niex> Exflect.inflect(\"leaf\", 2)\n\"leaves\"\n```\nAlso accepts the `match_style` option","ref":"Exflect.html#inflect/3"},{"type":"function","title":"Exflect.pluralize/2","doc":"Pluralizes an English word.\n\n```elixir\niex> Exflect.pluralize(\"leaf\")\n\"leaves\"\n```\n\nTakes the option `match_style` if you want it to maintain the current whitespace/case.\n```elixir\niex> Exflect.pluralize(\"  LEAF  \", match_style: true)\n\"  LEAVES  \"\n```","ref":"Exflect.html#pluralize/2"},{"type":"function","title":"Exflect.singularize/2","doc":"Singlarizes an English word.\n\n```elixir\niex> Exflect.singularize(\"leaves\")\n\"leaf\"\n```\n\nTakes the option `match_style` if you want it to maintain the current whitespace/case.\n```elixir\niex> Exflect.singularize(\"  LEAVES  \", match_style: true)\n\"  LEAF  \"\n```","ref":"Exflect.html#singularize/2"},{"type":"extras","title":"Exflect","doc":"# Exflect\n\nExflect is an Elixir inflection library for pluralization/singularization of English words.","ref":"readme.html"},{"type":"extras","title":"Installation - Exflect","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `exflect` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:exflect, \"~> 0.3.0\"}\n  ]\nend\n```\n\nDocumentation can be found on [HexDocs](https://hexdocs.pm/exflect).","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Exflect","doc":"```elixir\niex> Exflect.pluralize(\"leaf\")\n\"leaves\"\niex> Exflect.singularize(\"leaves\")\n\"leaf\"\n\niex> Exflect.inflect(\"leaf\", 0)\n\"leaves\"\niex> Exflect.inflect(\"leaf\", 1)\n\"leaf\"\niex> Exflect.inflect(\"leaf\", 2)\n\"leaves\"\n\niex> Exflect.pluralize(\"  LEAF   \", match_style: true)\n\"  LEAVES   \"\niex> Exflect.pluralize(\"  Leaf   \", match_style: true)\n\"  Leaves   \"\nExflect.singularize(\"  LEAVES   \", match_style: iex> true)\n\"  LEAF   \"\niex> Exflect.inflect(\"  LEAF  \", 2, match_style: true)\n\"  LEAVES  \"\n```","ref":"readme.html#usage"},{"type":"extras","title":"FAQ - Exflect","doc":"#","ref":"readme.html#faq"},{"type":"extras","title":"Why build a new library? - Exflect","doc":"The existing one seems to not longer be maintained, and it's quite inaccurate, and not very performant(mostly because of the heavy reliance on Regex).\n\nHere are some accuracy comparisons based on the test suite compiled from other OSS inflection libraries. I've purposely removed any test data that follows the default \"add 's'\"/\"remove 's'\" rule, as it has the least value when comparing accuracy. There are about 1500 words being tested. The performance results below are also based on the same test set.\n\n\n\n|exflect|91.1%|\n|-|-|\n|inflex|75.8%|\n\n\nIt would be possible to get Exflect higher scorewise, but that 10% is a lot of edge cases, or places where varying libraries disagree. Words like \"elk\" vs \"elks\", \"buffalo\" vs \"buffaloes\" vs \"buffalos\". Also Exflect doesn't currently handle phrases like \"lady in waiting\" correctly. You'll get \"lady in waitings\" rather than \"ladies in waiting\".\n\nHere are some performance benchmarks:\n\n```\nOperating System: macOS\nCPU Information: Apple M1 Pro\nNumber of Available Cores: 10\nAvailable memory: 16 GB\nElixir 1.15.3\nErlang 26.0\n\nBenchmark suite executing with the following configuration:\nwarmup: 2 s\ntime: 5 s\nmemory time: 2 s\nreduction time: 2 s\nparallel: 1\ninputs: none specified\nEstimated total run time: 33 s\n\nBenchmarking exflect ...\nBenchmarking inflex ...\nBenchmarking exflect_match_style ...\n\nName                          ips        average  deviation         median         99th %\nexflect                    846.64        1.18 ms     ±2.63%        1.17 ms        1.26 ms\nexflect_match_style        291.16        3.43 ms     ±2.23%        3.41 ms        3.76 ms\ninflex                      18.81       53.16 ms     ±0.18%       53.14 ms       53.44 ms\n\nComparison:\nexflect                    846.64\nexflect_match_style        291.16 - 2.91x slower +2.25 ms\ninflex                      18.81 - 45.00x slower +51.97 ms\n\nMemory usage statistics:\n\nName                   Memory usage\nexflect                     2.48 MB\nexflect_match_style         6.45 MB - 2.60x memory usage +3.97 MB\ninflex                      8.02 MB - 3.23x memory usage +5.53 MB\n\n**All measurements for memory usage were the same**\n\nReduction count statistics:\n\nName                Reduction count\nexflect                     87.88 K\nexflect_match_style        341.98 K - 3.89x reduction count +254.10 K\ninflex                    1415.14 K - 16.10x reduction count +1327.26 K\n\n**All measurements for reduction count were the same**\n```\n\nYou can run these benchmarks yourself by running the test suite with the `benchmark` tag:\n\n```\nmix test --include benchmark\n```\n\n#","ref":"readme.html#why-build-a-new-library"},{"type":"extras","title":"Is it ready for production use? - Exflect","doc":"It's still a work in progress, as there are some edge cases that aren't being covered, and some code clean up I'd like to do, but I don't imagine the API will change significantly as it's fairly straightforward.","ref":"readme.html#is-it-ready-for-production-use"},{"type":"extras","title":"Credits - Exflect","doc":"The existing Elixir library [Inflex](https://github.com/nurugger07/inflex) and the Python library [Inflect](https://github.com/jaraco/inflect) were both crucial in the devlopment of this code, so thanks to them for their work.","ref":"readme.html#credits"},{"type":"extras","title":"License - Exflect","doc":"MIT License\n\nCopyright (c) 2023 Peter Richards\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"readme.html#license"}],"content_type":"text/markdown"}